
# q-expansion of newform 961.2.d.n, downloaded from the LMFDB on 22 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 961
weight = 2
poly_data = [1, 0, 44, 0, 410, 0, 956, 0, 979, 0, 511, 0, 140, 0, 19, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[255, 0, 2839, 0, 3382, 0, 691, 0, -641, 0, -358, 0, -65, 0, -4, 0], 93], [[162, -1485, 2839, -4846, 3382, -8413, 691, -9398, -641, -5744, -358, -1792, -65, -267, -4, -15], 186], [[140, 0, -1035, 0, -33, 0, 3497, 0, 3517, 0, 1334, 0, 219, 0, 13, 0], 93], [[46, 0, 1128, 0, 33, 0, -3497, 0, -3517, 0, -1334, 0, -219, 0, -13, 0], 93], [[99, -172, 3235, -13108, 14763, -27739, 21039, -22302, 13157, -8815, 4011, -1832, 582, -192, 32, -8], 186], [[-52, -33, -860, -3765, 8206, -11369, 19069, -14174, 14478, -8581, 4887, -2608, 753, -380, 43, -21], 186], [[573, -1616, 9839, -14009, 29514, -34611, 35904, -37617, 21097, -20448, 6261, -5743, 897, -791, 49, -42], 186], [[-168, 1389, -2571, -3080, 4857, -25706, 14881, -39298, 11602, -25216, 3911, -7793, 599, -1140, 34, -63], 186], [[36, 1788, -926, 27117, -7987, 62350, -13483, 59919, -9222, 29263, -2966, 7575, -445, 983, -25, 50], 186], [[11, 261, -109, 6074, 7954, 18145, 16980, 21730, 12739, 12516, 4300, 3653, 664, 517, 38, 28], 186], [[36, -1788, -926, -27117, -7987, -62350, -13483, -59919, -9222, -29263, -2966, -7575, -445, -983, -25, -50], 186], [[-129, 1129, 926, 17792, 7987, 47440, 13483, 52048, 9222, 28357, 2966, 7993, 445, 1106, 25, 59], 186], [[168, 1389, 2571, -3080, -4857, -25706, -14881, -39298, -11602, -25216, -3911, -7793, -599, -1140, -34, -63], 186], [[-231, 2232, 1483, 37882, -1556, 99851, -8016, 109306, -7026, 59582, -2508, 16802, -397, 2325, -23, 124], 186], [[231, 2232, -1483, 37882, 1556, 99851, 8016, 109306, 7026, 59582, 2508, 16802, 397, 2325, 23, 124], 186]]

hecke_ring_character_values = [[3, [-1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, -1, 0, 0, 0]]]
aps_data = [[0, 0, 0, -1, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 1], [0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 1, 0, 0, 0], [0, 0, 0, -2, -1, -1, 0, -1, 0, 1, 0, 2, 0, 0, -1, 1], [0, 0, -1, 1, 1, 0, 0, 0, -1, -1, -1, 0, 0, 0, -1, 0], [0, 0, 0, -1, 0, 0, 0, 0, 0, 1, 1, 0, 2, 0, 0, 0], [1, -2, 1, 0, 0, 0, 1, 1, 0, 0, 0, 1, -1, 1, 0, 0], [0, -1, 0, 0, 1, 0, 0, 1, 0, 0, 2, -2, -2, 1, 0, 1], [2, 1, -1, 0, 1, 0, 1, 0, 0, 0, 1, 1, 3, 1, 1, 1], [-1, 0, 1, 0, 1, 1, 0, 0, 0, -2, 1, -4, -3, 1, 0, 0], [4, -1, 1, -1, 2, 0, 2, 0, 0, 3, 1, 1, 3, 2, 0, 1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-4, 1, 0, -3, 1, 1, 0, 1, 1, 0, 0, -1, 0, -1, -3, 3], [2, -1, 1, 1, 0, 0, 0, 0, 0, -3, 0, 0, 1, 2, 1, 0], [1, -2, 2, 3, 2, 1, 2, 0, 0, -3, -1, -1, -1, 0, 2, -1], [1, 0, 0, 1, 0, 0, 2, -2, -2, -2, -1, -3, 0, 2, -1, -1], [0, -5, 0, 0, 1, -4, 0, 1, 0, 0, 1, 2, -2, 1, 0, 2], [-3, -3, -2, -1, 0, 0, -1, 4, -2, 1, -2, -1, -3, -1, -2, 1], [5, -2, 0, 1, 0, 1, 0, 1, -2, -1, 0, -2, 0, 2, 1, -1], [-1, 1, 0, 1, 1, 0, 0, 0, 0, -2, 0, -2, 0, 0, 3, -3], [1, -2, -1, 0, 2, 0, 1, 2, -1, 1, 2, 2, 2, 2, 0, 2], [-1, 0, -3, 0, 5, 2, 2, 3, -5, 0, 0, -3, 0, 0, 0, 0], [-6, 4, -1, 0, -6, -2, -2, -3, 2, -3, -4, 0, -2, -6, 0, 0], [7, -3, 3, 3, -1, 2, -1, 0, 0, 6, -2, -2, 4, 2, 1, -2], [1, 0, 1, 2, 1, 2, 3, 0, -1, -2, -2, -1, 4, 0, -2, 0], [6, 0, 2, 1, -1, 1, 2, -2, 1, -1, -1, 5, 9, 0, 5, 0], [-1, -1, -2, 0, -2, -3, 1, -1, -1, 0, 1, -2, -5, -2, 0, 2], [-1, 2, -2, -1, 0, -1, 0, 0, 0, 7, -2, -2, 1, -2, -3, -2], [-1, -3, 4, 0, 3, 0, -2, 1, 2, -3, 1, -4, -4, 3, 0, -1], [-3, -1, -3, 0, 0, 0, -1, 2, 2, -2, -2, 3, -4, -1, -2, 0], [-7, 0, -1, 2, 2, 1, 0, 9, -2, -2, -2, -8, -3, 0, -1, 0], [-8, 2, -5, 3, 0, 0, -4, 2, -1, -7, -4, -4, -9, -4, -4, -3], [8, 0, 3, -4, -1, 2, 3, -3, 1, 4, 4, 6, 7, 0, 3, 0], [-1, -5, 4, -5, 0, 0, 1, 4, 0, 0, -2, 2, -4, 1, -2, 5], [-4, 4, 4, 1, 0, 0, -2, -2, 5, -12, -2, -5, -10, -2, -2, -1], [-4, 0, 0, 3, -6, -4, 0, -4, 4, 3, 0, 7, 0, -4, 3, -3], [-9, 0, 1, 2, 0, 1, -5, 4, 0, -2, -2, -10, -4, 0, 1, 0], [10, -3, 3, 1, 3, 8, 3, 0, 0, 4, 2, 2, 7, 4, 3, 2], [-8, -1, -4, 0, 1, 0, -2, 7, 2, -2, -2, -3, -3, 1, 0, 0], [-3, -3, 3, -3, 2, 1, 2, 0, 0, 9, 1, 1, -6, 3, -2, 1], [-2, 5, 2, -4, 0, 0, -2, -3, 5, 3, 0, 2, 6, -2, 0, 4], [4, 0, 0, 2, -2, -2, 4, -6, 2, -2, -2, 6, 11, 0, 2, 0], [7, -2, 0, 6, 7, 3, 0, 3, -4, -3, 0, -6, 0, 4, 3, -3], [6, -1, 0, 6, -2, 1, 0, 1, 2, 4, 0, 3, 0, -2, 4, -4], [-8, 0, -4, 6, 2, -2, -3, 7, -2, -6, -6, -6, -1, 0, -4, 0], [10, 0, 7, 4, 0, 7, 2, 1, 0, -4, -4, 3, 1, 0, 2, 0], [4, 2, -4, -3, 0, 0, 3, -5, -5, 6, 1, 11, 11, 3, 1, 3], [4, -10, 0, -2, 7, 4, 0, 4, -6, 6, 0, 2, 0, 6, -3, 3], [-5, -3, 0, 1, 1, 4, 0, 4, 0, -2, 0, -6, 0, 0, 1, -1], [15, -5, 5, 7, 4, 6, 4, 0, 0, 0, 0, 0, 10, 7, 7, 0], [2, 1, -1, -5, -3, -6, -3, 0, 0, -1, 7, 7, 3, 1, 2, 7], [-5, 1, 2, -3, 0, 0, -5, 4, 2, -2, 0, 3, -6, -5, 0, 3], [-2, -6, 2, 0, 2, -4, 6, -6, -6, -10, -1, -7, -11, 2, 0, -5], [-6, 0, 6, 2, 4, 10, 0, 4, -4, -2, -2, -16, -9, 0, -5, 0], [0, -6, -1, -3, 0, 0, -2, 8, 4, -1, 2, 10, -9, -2, 2, 3], [2, 7, 4, 0, -12, -5, -5, -11, 5, 3, 0, 7, 2, -12, 0, -7], [-1, -1, -5, -1, 0, 0, 4, -3, -7, -4, -5, 7, -1, 4, -5, 1], [3, 2, -2, 0, 2, -3, 2, 0, 0, -2, 4, 4, 5, -3, 4, 4], [-6, 0, -3, 0, 2, 2, -3, 8, 3, 0, 4, -7, -5, 2, 0, -2], [-1, -7, 7, -2, -2, -8, -2, 0, 0, -8, 0, 0, -8, 3, -2, 0], [-15, 1, -1, 0, -5, -12, -5, 0, 0, -15, -3, -3, -14, -1, -3, -3], [3, 0, 2, 4, 2, 4, -1, 1, -2, -4, -4, -1, -8, 0, 1, 0], [-10, 12, -2, 0, -6, 6, -4, 0, 4, -4, -1, -8, -2, -6, 0, -2], [5, -1, 4, 7, 0, 0, 0, 1, -8, -5, 5, -2, -6, 0, 5, -7], [7, -7, 0, -3, 5, 1, 0, 1, -1, 6, 0, 5, 0, 1, -3, 3], [-17, 6, -3, 0, 0, 0, -11, 5, 2, 5, -6, -7, 0, -11, -6, 0], [-4, 0, -5, -2, -3, -8, -3, -7, 3, 2, 2, 4, 4, 0, -2, 0], [-9, 9, -9, 12, -9, 2, -9, 0, 0, -8, -8, -8, 0, -5, 4, -8], [-3, 0, 4, -1, 5, 9, 2, 1, -5, 1, 1, -12, -10, 0, 3, 0], [-1, 6, 0, -9, -1, -5, 0, -5, 0, 3, 0, 8, 0, 0, -2, 2], [-4, -5, 4, 0, -5, -10, -7, -2, 7, -1, -6, 5, -5, -5, 0, -5], [-3, 12, -12, 0, 2, 5, 2, 0, 0, -2, 1, 1, 9, -2, 1, 1], [2, -2, -7, 1, 0, 0, 2, 0, -12, 3, 0, 9, 3, 2, 0, -1], [2, 5, 0, 11, -8, -5, 0, -5, 1, -3, 0, 2, 0, -1, 7, -7], [2, 2, 0, 0, -9, -2, 0, -2, -3, 0, 0, 2, 0, 3, 4, -4], [3, 0, 3, -4, -7, -4, -7, 0, 7, 4, 4, 7, -10, 0, 1, 0], [6, 0, 1, 2, -3, -2, 1, -10, 3, -2, -2, 8, 23, 0, 1, 0], [-14, -2, -7, 0, -5, -7, -2, 4, 2, -5, -4, -5, -12, -5, 0, -11], [5, 2, 0, -2, 2, -7, 0, -7, 1, -8, 0, -1, 0, -1, -2, 2], [-13, 11, -11, 15, -9, -6, -9, 0, 0, -15, -9, -9, -2, -18, 6, -9], [9, -1, 0, -1, -8, -1, 0, -1, 6, 3, 0, 4, 0, -6, 1, -1], [0, 1, 14, -8, 0, 0, 0, -1, 9, -4, 0, 3, -3, 0, 0, 8], [-1, 0, 9, 12, 0, 0, -2, 2, 4, -10, 1, -14, -12, -2, 1, -12], [4, 6, 4, 1, 0, 0, 0, -6, 10, -5, 4, 1, 1, 0, 4, -1], [-1, -3, 0, 14, 1, 6, 0, 6, 0, -16, 0, -22, 0, 0, 9, -9], [6, -5, 0, -1, 10, -4, 0, -4, -10, -5, 0, -1, 0, 10, -7, 7], [9, -11, 3, 0, 9, -2, 4, 2, -4, 2, 0, -2, -4, 9, 0, 8], [2, -3, 2, 0, 0, 0, -1, 4, 9, 12, 3, 2, 8, -1, 3, 0], [2, 11, 6, 0, -12, -1, -5, -13, 5, 1, -9, 8, 7, -12, 0, -3], [-6, 0, 5, 1, -4, 1, -10, 9, 4, -1, -1, -7, -2, 0, -5, 0], [7, 5, -5, -1, 3, -5, 3, 0, 0, 1, 0, 0, 12, 3, -1, 0], [-11, -1, 1, 16, 0, -8, 0, 0, 0, -6, -11, -11, -12, 1, 5, -11], [18, -3, 9, 0, 6, 3, 5, -8, -5, 4, -4, 1, 4, 6, 0, 4], [15, 0, 6, 0, 2, 2, 3, -7, -3, 6, 12, 12, 14, 2, 0, 4], [1, -3, 0, -8, 0, 5, 0, 5, -2, -1, 0, -6, 0, 2, -10, 10], [10, 10, -10, 8, 0, 0, 2, -12, -3, 10, 8, 10, 22, 2, 8, -8], [-3, 0, 2, 4, -4, -2, 4, -1, 4, -4, -4, -1, 2, 0, 9, 0], [-10, 0, -7, 11, 0, 0, 0, 0, -7, -10, -10, -10, -10, 0, -10, -11], [-2, 5, 0, -1, 7, -7, 0, -7, -4, -2, 0, 5, 0, 4, -1, 1], [8, 0, -8, -1, 3, -5, -7, -6, -3, 1, 1, 13, 6, 0, -6, 0], [-12, 9, -11, 0, -10, -1, -6, 7, 6, 5, 1, -6, -7, -10, 0, 1], [5, 0, 6, 3, 10, 16, -6, 2, -10, -3, -3, -11, 13, 0, -2, 0], [4, 1, 0, -8, 11, 12, 0, 12, -6, 4, 0, -8, 0, 6, -7, 7], [-22, 8, 0, -7, -8, -8, 0, -8, 7, -6, 0, 2, 0, -7, -4, 4], [14, 0, -10, -8, -7, -17, -5, -4, 7, 8, 8, 31, 22, 0, 8, 0], [5, 0, -9, -4, 0, 0, -4, 4, 7, 18, 9, 11, 14, -4, 9, 4], [10, -5, 5, -4, 3, -4, 3, 0, 0, 8, -1, -1, 5, -3, -5, -1], [3, 0, 0, -15, 11, 5, 11, 0, 0, -2, 13, 13, 3, 13, -2, 13], [-10, 0, 13, 2, -12, 1, -4, -10, 12, -2, -2, -11, -6, 0, -1, 0], [10, -12, 12, -13, 3, 1, 3, 0, 0, 10, 7, 7, -2, 2, -6, 7], [-11, 4, -4, -2, -6, -9, -6, 0, 0, -4, -6, -6, -7, -12, -8, -6], [13, -4, 6, -12, 0, 0, 15, -11, 2, 17, -2, 28, 28, 15, -2, 12], [1, 0, -4, 9, -3, -7, 2, 3, 3, -9, -9, 8, 2, 0, -1, 0], [-18, 6, 4, 2, 0, 0, -13, 7, 3, -15, -5, -21, -22, -13, -5, -2], [-6, -4, 0, -3, 4, -3, 0, -3, -2, 16, 0, 19, 0, 2, -7, 7], [-5, 0, -10, 3, 6, -4, 2, -8, -6, -3, -3, -1, -4, 0, -2, 0], [0, -11, 11, -1, -3, -6, -3, 0, 0, -13, -2, -2, -11, 11, -3, -2], [-13, 3, -6, 0, 2, 5, 4, 4, -4, -11, -6, -14, -9, 2, 0, -3], [11, 0, 4, 2, -4, 0, 8, 4, 4, -2, -2, 11, 12, 0, 7, 0], [4, -1, 1, -9, 14, 3, 14, 0, 0, -2, 11, 11, 3, 12, 2, 11], [-3, -4, -12, 0, 0, -4, -1, 13, 1, 10, -3, -4, -8, 0, 0, -2], [9, -6, 6, 3, 4, 8, 4, 0, 0, 6, 4, 4, 3, 9, 7, 4], [-6, 3, -12, 0, -9, -6, -2, 5, 2, 8, -6, 18, 12, -9, 0, 6], [8, -11, 0, 19, 13, 9, 0, 9, -2, -2, 0, -11, 0, 2, 6, -6], [7, 0, 0, -8, -13, -12, 0, -12, 10, -4, 0, 8, 0, -10, 1, -1], [-35, 11, -3, 0, -15, -4, -12, 0, 12, -20, -4, -21, -25, -15, 0, -6], [-6, -10, 10, 4, -8, -16, -8, 0, 0, -20, 1, 1, -16, 4, 5, 1], [4, 0, -9, -3, -13, -22, -2, -6, 13, 3, 3, 26, 1, 0, 4, 0], [16, -9, 0, 15, 14, 2, 0, 2, -5, -5, 0, -7, 0, 5, -2, 2], [12, -15, 7, 0, 7, -8, 11, -11, -11, -6, 2, 8, 0, 7, 0, 1], [0, 0, 7, 2, 1, 8, -13, 3, -1, -2, -2, -8, -6, 0, 1, 0], [-9, 12, 0, -4, -4, 1, 0, 1, -1, -6, 0, -7, 0, 1, 6, -6], [9, 3, 0, 8, 10, -3, 0, -3, -5, -10, 0, -7, 0, 5, -1, 1], [17, 0, 8, -1, 7, 15, -4, -5, -7, 1, 1, 2, -6, 0, -9, 0], [6, -10, 1, -13, 0, 0, 6, 4, 7, 1, 0, 2, -3, 6, 0, 13], [1, -5, 2, 0, 10, 5, 9, -1, -9, -10, 2, 12, 17, 10, 0, 7], [-5, 12, 0, 6, 0, -1, 0, -1, 5, -3, 0, -2, 0, -5, 3, -3], [20, -14, 14, 0, 5, 12, 5, 0, 0, 9, 0, 0, 6, 10, 0, 0], [-3, 11, -11, 17, 1, -2, 1, 0, 0, 5, -10, -10, 8, -2, 7, -10], [18, 2, 6, 0, 18, 20, 6, 6, -6, 6, -5, 4, 24, 18, 0, 6], [-3, 0, 16, -4, 0, 0, 2, -2, 8, -10, -5, -2, -8, 2, -5, 4], [-12, -12, 0, -2, -8, -4, 0, -4, 6, 11, 0, 15, 0, -6, -1, 1], [-21, -13, -10, -1, 0, 0, -7, 20, -1, 11, -14, -19, -9, -7, -14, 1], [-4, 7, 4, 0, 3, 10, -6, 5, 6, -2, 4, -14, -4, 3, 0, 11], [-4, 7, -7, -6, 4, -5, 4, 0, 0, -1, 6, 6, 3, -1, 0, 6], [15, 3, -13, 0, 3, 6, 6, 10, -6, 22, -4, 11, 17, 3, 0, 1], [0, 15, -15, -11, -3, 6, -3, 0, 0, 4, 1, 1, 15, -11, -10, 1], [9, -2, 10, 16, 0, 0, 5, -3, 7, -6, 4, -12, -3, 5, 4, -16], [6, 0, -8, 10, 2, -6, 14, 2, -2, -10, -10, 12, 3, 0, 1, 0], [-2, 3, 2, 0, 6, 9, -5, 9, 5, 1, 4, -21, -12, 6, 0, 1], [17, -3, 0, -9, -2, -3, 0, -3, 1, 31, 0, 34, 0, -1, -5, 5], [2, -1, 11, 0, -9, -10, -7, -13, 7, -2, -9, 24, 14, -9, 0, 4], [0, -2, -9, 4, 0, 0, -5, 7, -5, 18, 5, 6, 11, -5, 5, -4], [8, 5, -3, -4, 0, 0, -3, -2, 0, -11, 11, -18, -9, -3, 11, 4], [29, -14, 14, 6, 9, 11, 9, 0, 0, 7, 3, 3, 15, 9, 9, 3], [17, 5, -4, 0, 5, 10, 10, -1, -10, 11, 2, 1, 11, 5, 0, -6], [29, -17, 17, -1, -3, -2, -3, 0, 0, 27, 6, 6, 12, 12, 5, 6], [22, 0, 1, -14, 4, 5, 10, -1, -4, 14, 14, 17, -2, 0, -3, 0], [-8, 0, 0, 17, -1, -20, 0, -20, 7, -24, 0, -4, 0, -7, 7, -7], [1, 0, -6, 9, -8, -14, 9, -9, 8, -9, -9, 15, 7, 0, 7, 0], [-8, 0, -5, -10, 0, -5, -5, -3, 0, 10, 10, -3, -12, 0, -20, 0], [13, -4, -13, 0, -14, -18, 4, -5, -4, 22, -5, 34, 16, -14, 0, -7], [16, -7, 8, 0, 16, 9, 8, 0, -8, 0, 12, -5, 4, 16, 0, 3], [-26, 8, 0, -5, -5, -16, 0, -16, 0, -30, 0, -14, 0, 0, -3, 3], [-27, 24, -24, 10, -4, -10, -4, 0, 0, -18, -12, -12, -3, -17, -2, -12], [22, -4, 6, -5, 0, 0, 11, -7, 2, 4, 11, -10, 11, 11, 11, 5], [-17, -6, 8, 0, 0, -6, -5, -3, 5, -20, 5, -19, -25, 0, 0, 9], [5, -9, 0, -22, -7, 0, 0, 0, -1, 19, 0, 19, 0, 1, -1, 1], [10, -6, 0, 19, 12, 5, 0, 5, -9, -14, 0, -19, 0, 9, 7, -7]]
